package com.xinelu.manage.service.textmessage;

import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.dto.textmessage.TextMessageDTO;
import com.xinelu.manage.dto.textmessage.TextMessageTaskDTO;
import com.xinelu.manage.vo.textmessage.TextMessageTaskVO;

import java.util.List;

/**
 * 短信模板信息Service接口
 *
 * @author xinelu
 * @date 2024-02-28
 */
public interface ITextMessageService {
    /**
     * 查询短信模板信息
     *
     * @param id 短信模板信息主键
     * @return 短信模板信息
     */
    public TextMessageTaskVO selectTextMessageById(Long id);

    /**
     * 查询短信模板信息列表
     *
     * @param textMessageDTO 短信模板信息
     * @return 短信模板信息集合
     */
    public List<TextMessageTaskVO> selectTextMessageList(TextMessageDTO textMessageDTO);

    /**
     * 新增短信模板信息
     *
     * @param textMessageTaskDTO 短信模板信息
     * @return 结果
     */
    public int insertTextMessage(TextMessageTaskDTO textMessageTaskDTO);

    /**
     * 修改短信模板信息
     *
     * @param textMessageTaskDTO 短信模板信息
     * @return 结果
     */
    public int updateTextMessage(TextMessageTaskDTO textMessageTaskDTO);

    /**
     * 批量删除短信模板信息
     *
     * @param ids 需要删除的短信模板信息主键集合
     * @return 结果
     */
    public int deleteTextMessageByIds(Long[] ids);

    /**
     * 删除短信模板信息信息
     *
     * @param id 短信模板信息主键
     * @return 结果
     */
    public int deleteTextMessageById(Long id);

    /**
     * 查询话术变量
     */
    AjaxResult selectTextMessageVariable(Long id);
}
